==> CGAL-5.2.2-doc_html.tar.xz: doc_html/HalfedgeDS/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.2.2 - Halfedge Data Structures", "index.html", [
    [ "User Manual", "index.html", [
      [ "Introduction", "index.html#HalfedgeDSIntroduction", null ],
      [ "Software Design", "index.html#HalfedgeDSSoftware", null ],
      [ "Example Programs", "index.html#HalfedgeDSExample", [
        [ "The Default Halfedge Data Structure", "index.html#HalfedgeDSTheDefaultHalfedgeDataStructure", null ],
        [ "A Minimal Halfedge Data Structure", "index.html#HalfedgeDSAMinimalHalfedgeDataStructure", null ],
        [ "The Default with a Vector Instead of a List", "index.html#HalfedgeDSTheDefaultwithaVectorInsteadof", null ],
        [ "Example Adding Color to Faces", "index.html#HalfedgeDSExampleAddingColortoFaces", null ],
        [ "Example Defining a More Compact Halfedge", "index.html#HalfedgeDSExampleDefiningaMoreCompactHalfedge", null ],
        [ "Example Using the Halfedge Iterator", "index.html#HalfedgeDSExampleUsingtheHalfedgeIterator", null ],
        [ "Example for an Adapter to Build an Edge Iterator", "index.html#HalfedgeDSExampleforanAdaptertoBuildanEdge", null ]
      ] ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Refinement Relationships", "refines.html", null ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"HalfedgeDS_2hds_prog_color_8cpp-example.html",
"classHalfedgeDSVertex.html#a0266c0cea79e1a21c79048b9defa92f1"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> CGAL-5.4.1-doc_html.tar.xz: doc_html/HalfedgeDS/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.4.1 - Halfedge Data Structures", "index.html", [
    [ "User Manual", "index.html", [
      [ "Introduction", "index.html#HalfedgeDSIntroduction", null ],
      [ "Software Design", "index.html#HalfedgeDSSoftware", null ],
      [ "Example Programs", "index.html#HalfedgeDSExample", [
        [ "The Default Halfedge Data Structure", "index.html#HalfedgeDSTheDefaultHalfedgeDataStructure", null ],
        [ "A Minimal Halfedge Data Structure", "index.html#HalfedgeDSAMinimalHalfedgeDataStructure", null ],
        [ "The Default with a Vector Instead of a List", "index.html#HalfedgeDSTheDefaultwithaVectorInsteadof", null ],
        [ "Example Adding Color to Faces", "index.html#HalfedgeDSExampleAddingColortoFaces", null ],
        [ "Example Defining a More Compact Halfedge", "index.html#HalfedgeDSExampleDefiningaMoreCompactHalfedge", null ],
        [ "Example Using the Halfedge Iterator", "index.html#HalfedgeDSExampleUsingtheHalfedgeIterator", null ],
        [ "Example for an Adapter to Build an Edge Iterator", "index.html#HalfedgeDSExampleforanAdaptertoBuildanEdge", null ]
      ] ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Refinement Relationships", "refines.html", null ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"HalfedgeDS_2hds_prog_color_8cpp-example.html",
"classHalfedgeDSHalfedge.html#afb0a093377537b558329d42c386f031e"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
